@@ -9,7 +9,7 @@
 #' @param centerID A vector of length 1, representing a single Spot_ID that serves as the center for the neighborhood.
 #' @param radius The radius of the spatial neighborhood, specified as a numeric value.
 #' @param enhanced Logical; if `TRUE`, enhances the Seurat object by marking the neighborhood in a special way. Defaults to `FALSE`.
-#' @param avern Numeric; the number of samples to average over when determining the unit distance. Defaults to 5.
+#' @param unitDist Numeric; the unit distance of the spatial transcriptomics based on its spatial coordinates.
 #'
 #' @return A list containing:
 #' \describe{
@@ -25,27 +25,25 @@ Find_regional_IDs <- function(object,
                               centerID,
                               enhanced = FALSE,
                               radius  ,
-                              avern = 5) {
+                              unitDist) {
 
   stopifnot(exprs = {
     is.character(centerID)
     is.numeric(radius)
-    is.numeric(avern)
+    is.numeric(unitDist)
   })
 
-  #xloc <- object@images$slice1@coordinates$imagecol
-  #yloc <- object@images$slice1@coordinates$imagerow
   xloc <- spatial_coord$imagecol
   yloc <- spatial_coord$imagerow
 
-  ID <- sample(seq_len(length(xloc)), size = avern)
+  #ID <- sample(seq_len(length(xloc)), size = avern)
 
-  rec_minDist <- rep(NA, avern)
+  #rec_minDist <- rep(NA, avern)
 
-  for(i in seq_len(avern)) {
-    rec_minDist[i] <- min(sqrt((xloc[ID[i]] - xloc[-ID[i]])^2 + (yloc[ID[i]] - yloc[-ID[i]])^2))
-  }
-  unitDist <- mean(rec_minDist)
+  #for(i in seq_len(avern)) {
+  #  rec_minDist[i] <- min(sqrt((xloc[ID[i]] - xloc[-ID[i]])^2 + (yloc[ID[i]] - yloc[-ID[i]])^2))
+  #}
+  #unitDist <- mean(rec_minDist)
 
 
   if(enhanced) {
@@ -158,7 +156,8 @@ random_region <- function(spatial_coord, center_id, n_ids){
 #' }
 #'
 #' @importFrom nnls nnls
-#' @importFrom stats p.adjust 
+#' @importFrom FNN get.knn
+#' @importFrom stats p.adjust median
 #' @importFrom utils txtProgressBar setTxtProgressBar
 #'
 #' @export
@@ -176,11 +175,18 @@ SpaCCI_local <- function(gene_spot_df,
   #centerIDs <- c(colnames(gene_spot_df))
   RegionIDs_matrix <- list()
   message(paste0("Now finding the neighborhoods for ",round(ncol(gene_spot_df)*prop), " spots"))
+  xy <- as.matrix(spatial_coord[, c("imagecol","imagerow")])
+  nn <- get.knn(xy, k=1)
+  unitDist <- median(nn$nn.dist)
   for ( i in 1:length(centerIDs)){
-    IDs <- Find_regional_IDs(gene_spot_df,spatial_coord, centerIDs[i], enhanced = FALSE, radius = radius, avern = 5)$closeID
+    IDs <- Find_regional_IDs(gene_spot_df,spatial_coord, centerIDs[i], enhanced = FALSE, radius = radius, unitDist = unitDist)$closeID
     RegionIDs_matrix[[centerIDs[i]]] <- IDs
   }
   RegionIDs_matrix <- RegionIDs_matrix[sapply(RegionIDs_matrix, length) >= 6] # remove those that don't have enough neighborhoods
+  if (length(RegionIDs_matrix)==0){
+    stop("Please increase the cell/spot proportion for doing local analysis")
+  }
+  
   centerIDs <- names(RegionIDs_matrix) # update cencter ID
 
   ## prepared for permutation
@@ -198,8 +204,9 @@ SpaCCI_local <- function(gene_spot_df,
     }else if(nboot > 1000){
       nboot <- 1000
     }
-
-    premut_center <- sample(colnames(gene_spot_df[,-which(colnames(gene_spot_df) %in% ids )]), size = nboot)
+    available_cols <- setdiff(colnames(gene_spot_df), ids)
+    premut_center <- sample(available_cols, size = nboot, replace = TRUE)
+    #premut_center <- sample(colnames(gene_spot_df[,-which(colnames(gene_spot_df) %in% ids )]), size = nboot,replace = TRUE)
     region_permut_index <- vector("list", length(premut_center))
 
     # Loop through each center ID
