@@ -441,6 +441,7 @@ plot_Strength_Seurat <- function(Seurat_object,
 #'
 #' @importFrom ggplot2 ggplot aes geom_point scale_color_gradient2 labs xlim ylim theme element_blank element_text element_rect margin unit
 #' @importFrom dplyr %>% filter select mutate arrange group_by summarise
+#' @importFrom rlang .data
 #'
 #' @return The localized plot from the inferred cell-cell interaction on the local scale.
 #'
@@ -538,10 +539,11 @@ plot_localized <- function(spatial_coord,
 
   min_value <- 0
 
-  max_value <-  ceiling(max(spatial_coord$CCIcount ))
+  #max_value <-  ceiling(max(spatial_coord$CCIcount ))
+  max_value <- 1
+  spatial_coord$CCIcount_scaled <- spatial_coord$CCIcount / max(spatial_coord$CCIcount)
 
-
-  p_all_average <- ggplot(spatial_coord, aes(x = imagecol, y = imagerow, colour = CCIcount)) +
+  p_all_average <- ggplot(spatial_coord, aes(x = imagecol, y = imagerow, colour = .data$CCIcount_scaled)) +
     geom_point(alpha = 0.9, size = plot_size, stroke = 0, shape = 16) +
     #scale_colour_gradient(low = "#F0F0F0", high = '#F29403') +
     scale_color_gradient2(low = "black", mid = "purple", high = "yellow", limits = c(0, max_value), midpoint = max_value / 2, space = "Lab") +
